# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`patching_as_code`](#patching_as_code): Framework for patch management as code. Works alongside the puppetlabs/pe_patch or albatrossflavour/os_patching modules

## Classes

### patching_as_code

Framework for patch management as code. Works alongside the puppetlabs/pe_patch or albatrossflavour/os_patching modules

#### Examples

##### Using the module with defaults, or controlling options through Hiera

```puppet
include patching_as_code
```

##### Forcing the classification of pe_patch on PE 2019.8.0+

```puppet
class {'patching_as_code':
  classify_pe_patch => true
}
```

##### Forcing the use of albatrossflavour/os_patching on PE 2019.8.0+

```puppet
class {'patching_as_code':
  use_pe_patch => false
}
```

#### Parameters

The following parameters are available in the `patching_as_code` class.

##### `patch_group`

Data type: `String`

Name of the patch_group for this node. Must match one of the patch groups in $patch_schedule

##### `patch_schedule`

Data type: `Hash`

Hash of available patch_schedules. Default schedules are in /data/common.yaml of this module

Options:

* **:day_of_week** `String`: Day of the week to patch, valid options: 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday', 'Sunday'
* **:count_of_week** `Integer`: Which week in the month to patch, use a number between 1 and 4
* **:hours** `String`: Which hours on patch day to patch, define a range as 'HH:MM - HH:MM'
* **:max_runs** `String`: How many Puppet runs during the patch window can Puppet install patches. Must be at least 1.
* **:reboot** `String`: Reboot behavior, valid options: 'always', 'never', 'ifneeded'

##### `blocklist`

Data type: `Array`

List of updates to block from installing

##### `allowlist`

Data type: `Array`

List of updates that are allowed to be installed. Any updates not on this list get blocked.

##### `unsafe_process_list`

Data type: `Array`

List of processes that will cause patching to be skipped if any of the processes in the list are active on the system.

##### `pre_patch_commands`

Data type: `Hash`

Hash of command to run before patching

Options:

* **:command** `String`: The pre-patching command to execute
* **:path** `String`: The path for the command
* **:provider** `String`: The provider for the command

##### `post_patch_commands`

Data type: `Hash`

Hash of command to run after patching

Options:

* **:command** `String`: The post-patching command to execute
* **:path** `String`: The path for the command
* **:provider** `String`: The provider for the command

##### `pre_reboot_commands`

Data type: `Hash`

Hash of command to run before rebooting

Options:

* **:command** `String`: The pre-reboot command to execute
* **:path** `String`: The path for the command
* **:provider** `String`: The provider for the command

##### `use_pe_patch`

Data type: `Optional[Boolean]`

Use the pe_patch module if available (PE 2019.8+). Defaults to true.

Default value: `true`

##### `classify_pe_patch`

Data type: `Optional[Boolean]`

Controls if the pe_patch class (PE 2019.8+) is controlled by this module.
When enabled, this module will classify the node with pe_patch,
and set it's patch_group according to this module's patch_group.
When disabled (default), you can use PE's own "PE Patch Management" groups
to classify nodes with pe_patch. In that case, please make sure you match
the patch_group variable in pe_patch with the patch_group in patching_as_code

Default value: `false`

##### `patch_on_metered_links`

Data type: `Optional[Boolean]`

Controls if patches are installed when the active network connection is a
metered link. This setting only has affect for Windows operating systems.
When enabled, patching are installed even over a metered link.
When disabled (default), patches are not installed over a metered link.

Default value: `false`

